@@ -1,23 +1,8 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     V4fr3e <V4fr3e@deepin.io>
-*
-* Maintainer: V4fr3e <liujinli@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "vnoteitemoper.h"
 #include "vnotefolderoper.h"
 #include "vnotedbmanager.h"
@@ -227,8 +212,9 @@ QString VNoteItemOper::getDefaultNoteName(qint64 folderId)
 
     QString defaultNoteName = DApplication::translate("DefaultName", "Text");
 
-    if (nullptr != folder) {
-        defaultNoteName += QString("%1").arg(folder->maxNoteIdRef() + 1);
+    // 文本， 文本1， 文本2
+    if (nullptr != folder && folder->maxNoteIdRef() != 0) {
+        defaultNoteName += QString("%1").arg(folder->maxNoteIdRef());
     }
 
     return defaultNoteName;
