@@ -1,23 +1,7 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     liuyanga <liuyanga@uniontech.com>
-*
-* Maintainer: liuyanga <liuyanga@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifndef VNOTEMAINWINDOW_H
 #define VNOTEMAINWINDOW_H
@@ -308,6 +292,7 @@ private:
 
     DPushButton *m_addNotepadBtn {nullptr};
     DFloatingButton *m_addNoteBtn {nullptr};
+    DAnchorsBase *m_buttonAnchor {nullptr};
 
     VNoteRecordBar *m_recordBar {nullptr};
     VNoteA2TManager *m_a2tManager {nullptr};
@@ -337,6 +322,7 @@ private:
     QScopedPointer<QShortcut> m_stPlayorPause; //Space
     QScopedPointer<QShortcut> m_stRecording; //Ctrl+R
     QScopedPointer<QShortcut> m_stVoice2Text; //Ctrl+W
+    QScopedPointer<QShortcut> m_stVoice2Mp3; //Ctrl+P
     QScopedPointer<QShortcut> m_stSaveAsText; //Ctrl+S
     QScopedPointer<QShortcut> m_stSaveVoices; //Ctrl+Y
     QScopedPointer<QShortcut> m_stDelete; //Delete
