@@ -1,21 +1,21 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="hi_IN" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hi_IN">
 <context>
     <name>AppMain</name>
     <message>
-        <location filename="../src/common/vlcpalyer.cpp" line="54"/>
-        <location filename="../src/main.cpp" line="76"/>
-        <location filename="../src/main.cpp" line="77"/>
-        <location filename="../src/views/vnotemainwindow.cpp" line="605"/>
+        <location filename="src/common/vlcpalyer.cpp" line="54"/>
+        <location filename="src/main.cpp" line="94"/>
+        <location filename="src/main.cpp" line="95"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="615"/>
         <source>Voice Notes</source>
         <translation>वाणी नोट्स</translation>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="78"/>
+        <location filename="src/main.cpp" line="96"/>
         <source>Voice Notes is a lightweight memo tool to make text notes and voice recordings.</source>
         <translation>वाणी नोट्स, टेक्स्ट नोट्स व वाणी रिकॉर्डिंग बनाने हेतु एक सरल ज्ञापन साधन है।</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="606"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="616"/>
         <source>Recordings not saved</source>
         <translation>रिकॉर्डिंग संचित हुई</translation>
     </message>
@@ -23,18 +23,18 @@
 <context>
     <name>DefaultName</name>
     <message>
-        <location filename="../src/db/vnotefolderoper.cpp" line="245"/>
+        <location filename="src/db/vnotefolderoper.cpp" line="245"/>
         <source>Notebook</source>
         <translation>नोटबुक</translation>
     </message>
     <message>
-        <location filename="../src/db/vnoteitemoper.cpp" line="228"/>
+        <location filename="src/db/vnoteitemoper.cpp" line="228"/>
         <source>Text</source>
         <translation>टेक्स्ट</translation>
     </message>
     <message>
-        <location filename="../src/db/vnoteitemoper.cpp" line="243"/>
-        <location filename="../src/importolddata/olddbvisistors.cpp" line="154"/>
+        <location filename="src/db/vnoteitemoper.cpp" line="243"/>
+        <location filename="src/importolddata/olddbvisistors.cpp" line="154"/>
         <source>Voice</source>
         <translation>वाणी</translation>
     </message>
@@ -42,7 +42,7 @@
 <context>
     <name>DetailPage</name>
     <message>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="213"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="213"/>
         <source>%1 notes selected</source>
         <translation>%1 नोट्स चयनित</translation>
     </message>
@@ -50,18 +50,18 @@
 <context>
     <name>FolderSelectDialog</name>
     <message>
-        <location filename="../src/dialog/folderselectdialog.cpp" line="217"/>
+        <location filename="src/dialog/folderselectdialog.cpp" line="217"/>
         <source>Move Notes</source>
         <translation>नोट्स अंतरण</translation>
     </message>
     <message>
-        <location filename="../src/dialog/folderselectdialog.cpp" line="244"/>
+        <location filename="src/dialog/folderselectdialog.cpp" line="244"/>
         <source>Cancel</source>
         <comment>button</comment>
         <translation>रद्द करें</translation>
     </message>
     <message>
-        <location filename="../src/dialog/folderselectdialog.cpp" line="245"/>
+        <location filename="src/dialog/folderselectdialog.cpp" line="245"/>
         <source>Confirm</source>
         <comment>button</comment>
         <translation>पुष्टि करें</translation>
@@ -70,12 +70,12 @@
 <context>
     <name>HomePage</name>
     <message>
-        <location filename="../src/views/homepage.cpp" line="48"/>
+        <location filename="src/views/homepage.cpp" line="48"/>
         <source>Create Notebook</source>
         <translation>नोटबुक बनाएँ</translation>
     </message>
     <message>
-        <location filename="../src/views/homepage.cpp" line="60"/>
+        <location filename="src/views/homepage.cpp" line="60"/>
         <source>Create a notebook to start recording voice and making notes</source>
         <translation>वाणी रिकॉर्ड कर नोट्स बनाने हेतु नोटबुक बनाएँ</translation>
     </message>
@@ -83,28 +83,28 @@
 <context>
     <name>LeftView</name>
     <message>
-        <location filename="../src/dialog/folderselectdialog.cpp" line="381"/>
-        <location filename="../src/dialog/folderselectdialog.cpp" line="384"/>
-        <location filename="../src/dialog/folderselectdialog.cpp" line="392"/>
-        <source>Move the note &quot;%1&quot; to:</source>
-        <translation>नोट &quot;%1&quot; को यहाँ अंतरित करें :</translation>
-    </message>
-    <message>
-        <location filename="../src/dialog/folderselectdialog.cpp" line="380"/>
-        <location filename="../src/dialog/folderselectdialog.cpp" line="394"/>
+        <location filename="src/dialog/folderselectdialog.cpp" line="380"/>
+        <location filename="src/dialog/folderselectdialog.cpp" line="394"/>
         <source>Move %1 notes (%2, ...) to:</source>
         <translation>%1 नोट (%2, ...) यहाँ अंतरित करें :</translation>
     </message>
+    <message>
+        <location filename="src/dialog/folderselectdialog.cpp" line="381"/>
+        <location filename="src/dialog/folderselectdialog.cpp" line="384"/>
+        <location filename="src/dialog/folderselectdialog.cpp" line="392"/>
+        <source>Move the note &quot;%1&quot; to:</source>
+        <translation>नोट &quot;%1&quot; को यहाँ अंतरित करें :</translation>
+    </message>
 </context>
 <context>
     <name>MiddleView</name>
     <message>
-        <location filename="../src/views/middleview.cpp" line="276"/>
+        <location filename="src/views/middleview.cpp" line="303"/>
         <source>Save</source>
         <translation>संचित करें</translation>
     </message>
     <message>
-        <location filename="../src/views/middleview.cpp" line="1070"/>
+        <location filename="src/views/middleview.cpp" line="1057"/>
         <source>No search results</source>
         <translation>खोजने पर कोई परिणाम नहीं मिला</translation>
     </message>
@@ -112,7 +112,7 @@
 <context>
     <name>MiddleViewDelegate</name>
     <message>
-        <location filename="../src/views/middleviewdelegate.cpp" line="442"/>
+        <location filename="src/views/middleviewdelegate.cpp" line="442"/>
         <source>Sticky Notes</source>
         <translation>तारांकित नोट्स</translation>
     </message>
@@ -120,77 +120,77 @@
 <context>
     <name>NoteDetailContextMenu</name>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="282"/>
+        <location filename="src/common/actionmanager.cpp" line="276"/>
         <source>Save as MP3</source>
         <translation>Mp3 के रूप में संचित करें</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="283"/>
+        <location filename="src/common/actionmanager.cpp" line="277"/>
         <source>Voice to Text</source>
         <translation>वाणी से टेक्स्ट</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="284"/>
-        <location filename="../src/common/actionmanager.cpp" line="311"/>
-        <location filename="../src/common/actionmanager.cpp" line="337"/>
+        <location filename="src/common/actionmanager.cpp" line="278"/>
+        <location filename="src/common/actionmanager.cpp" line="305"/>
+        <location filename="src/common/actionmanager.cpp" line="331"/>
         <source>Delete</source>
         <translation>हटाएँ</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="285"/>
-        <location filename="../src/common/actionmanager.cpp" line="312"/>
-        <location filename="../src/common/actionmanager.cpp" line="338"/>
+        <location filename="src/common/actionmanager.cpp" line="279"/>
+        <location filename="src/common/actionmanager.cpp" line="306"/>
+        <location filename="src/common/actionmanager.cpp" line="332"/>
         <source>Select all</source>
         <translation>सभी चयनित करें</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="286"/>
-        <location filename="../src/common/actionmanager.cpp" line="313"/>
-        <location filename="../src/common/actionmanager.cpp" line="339"/>
+        <location filename="src/common/actionmanager.cpp" line="280"/>
+        <location filename="src/common/actionmanager.cpp" line="307"/>
+        <location filename="src/common/actionmanager.cpp" line="333"/>
         <source>Copy</source>
         <translation>कॉपी करेें</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="287"/>
-        <location filename="../src/common/actionmanager.cpp" line="314"/>
-        <location filename="../src/common/actionmanager.cpp" line="340"/>
+        <location filename="src/common/actionmanager.cpp" line="281"/>
+        <location filename="src/common/actionmanager.cpp" line="308"/>
+        <location filename="src/common/actionmanager.cpp" line="334"/>
         <source>Cut</source>
         <translation>कट करें</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="288"/>
-        <location filename="../src/common/actionmanager.cpp" line="315"/>
-        <location filename="../src/common/actionmanager.cpp" line="341"/>
+        <location filename="src/common/actionmanager.cpp" line="282"/>
+        <location filename="src/common/actionmanager.cpp" line="309"/>
+        <location filename="src/common/actionmanager.cpp" line="335"/>
         <source>Paste</source>
         <translation>पेस्ट करें</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="310"/>
+        <location filename="src/common/actionmanager.cpp" line="304"/>
         <source>View</source>
         <translation>देखें</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="316"/>
+        <location filename="src/common/actionmanager.cpp" line="310"/>
         <source>Save as</source>
         <translation>इस रूप में संचित करें</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="342"/>
+        <location filename="src/common/actionmanager.cpp" line="336"/>
         <source>Text to Speech</source>
         <translation>वाणी से टेक्स्ट</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="343"/>
+        <location filename="src/common/actionmanager.cpp" line="337"/>
         <source>Stop reading</source>
         <translation>पढ़ना रोकें</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="344"/>
+        <location filename="src/common/actionmanager.cpp" line="338"/>
         <source>Speech to Text</source>
         <translation>टेक्स्ट से वाणी</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="345"/>
+        <location filename="src/common/actionmanager.cpp" line="339"/>
         <source>Translate</source>
         <translation>अनुवाद</translation>
     </message>
@@ -198,17 +198,17 @@
 <context>
     <name>NotebookContextMenu</name>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="226"/>
+        <location filename="src/common/actionmanager.cpp" line="220"/>
         <source>Rename</source>
         <translation>नाम बदलें</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="227"/>
+        <location filename="src/common/actionmanager.cpp" line="221"/>
         <source>Delete</source>
         <translation>हटाएँ</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="228"/>
+        <location filename="src/common/actionmanager.cpp" line="222"/>
         <source>New note</source>
         <translation>नया नोट</translation>
     </message>
@@ -216,64 +216,64 @@
 <context>
     <name>NotesContextMenu</name>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="246"/>
-        <source>Rename</source>
-        <translation>नाम बदलें</translation>
-    </message>
-    <message>
-        <location filename="../src/common/actionmanager.cpp" line="248"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="336"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="345"/>
-        <source>Move</source>
-        <translation>अंतरित करें</translation>
-    </message>
-    <message>
-        <location filename="../src/common/actionmanager.cpp" line="249"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="338"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="344"/>
-        <source>Delete</source>
-        <translation>हटाएँ</translation>
-    </message>
-    <message>
-        <location filename="../src/common/actionmanager.cpp" line="201"/>
-        <source>Save as TXT</source>
-        <translation>txt के रूप में संचित करें</translation>
-    </message>
-    <message>
-        <location filename="../src/common/actionmanager.cpp" line="200"/>
+        <location filename="src/common/actionmanager.cpp" line="195"/>
         <source>Save as HTML</source>
         <translation>एचटीएमएल के रूप में संचित करें</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="205"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="342"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="353"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="359"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="361"/>
+        <location filename="src/common/actionmanager.cpp" line="196"/>
+        <source>Save as TXT</source>
+        <translation>txt के रूप में संचित करें</translation>
+    </message>
+    <message>
+        <location filename="src/common/actionmanager.cpp" line="200"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="342"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="353"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="359"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="361"/>
         <source>Save note</source>
         <translation>नोट संचित करें</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="251"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="343"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="354"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="366"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="368"/>
+        <location filename="src/common/actionmanager.cpp" line="240"/>
+        <source>Rename</source>
+        <translation>नाम बदलें</translation>
+    </message>
+    <message>
+        <location filename="src/common/actionmanager.cpp" line="242"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="336"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="345"/>
+        <source>Move</source>
+        <translation>अंतरित करें</translation>
+    </message>
+    <message>
+        <location filename="src/common/actionmanager.cpp" line="243"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="338"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="344"/>
+        <source>Delete</source>
+        <translation>हटाएँ</translation>
+    </message>
+    <message>
+        <location filename="src/common/actionmanager.cpp" line="245"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="343"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="354"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="366"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="368"/>
         <source>Save voice recording</source>
         <translation>वाणी रिकॉर्डिंग संचित करें</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="252"/>
+        <location filename="src/common/actionmanager.cpp" line="246"/>
         <source>New note</source>
         <translation>नया नोट</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="1240"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="1258"/>
         <source>Unstick</source>
         <translation>तारांकन हटाएँ</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="1242"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="1260"/>
         <source>Sticky on Top</source>
         <translation>शीर्ष पर तारांकित</translation>
     </message>
@@ -281,22 +281,22 @@
 <context>
     <name>Setting</name>
     <message>
-        <location filename="../src/common/setting.cpp" line="41"/>
+        <location filename="src/common/setting.cpp" line="39"/>
         <source>Basic</source>
         <translation>सामान्य</translation>
     </message>
     <message>
-        <location filename="../src/common/setting.cpp" line="42"/>
+        <location filename="src/common/setting.cpp" line="40"/>
         <source>Audio Source</source>
         <translation>ऑडियो स्रोत</translation>
     </message>
     <message>
-        <location filename="../src/common/setting.cpp" line="43"/>
+        <location filename="src/common/setting.cpp" line="41"/>
         <source>Internal</source>
         <translation>आंतरिक</translation>
     </message>
     <message>
-        <location filename="../src/common/setting.cpp" line="44"/>
+        <location filename="src/common/setting.cpp" line="42"/>
         <source>Microphone</source>
         <translation>माइक्रोफोन</translation>
     </message>
@@ -304,87 +304,87 @@
 <context>
     <name>Shortcuts</name>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="902"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="919"/>
         <source>New notebook</source>
         <translation>नई नोटबुक</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="903"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="920"/>
         <source>Rename notebook</source>
         <translation>नोटबुक का नाम बदलें</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="904"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="921"/>
         <source>Delete notebook</source>
         <translation>नोटबुक हटाएँ</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="926"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="943"/>
         <source>New note</source>
         <translation>नया नोट</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="927"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="944"/>
         <source>Rename note</source>
         <translation>नोट का नाम बदलें</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="928"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="945"/>
         <source>Delete note</source>
         <translation>नोट हटाएँ</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="929"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="946"/>
         <source>Play/Pause</source>
         <translation>चालू करें/ रोकें</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="930"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="947"/>
         <source>Record voice</source>
         <translation>वाणी रिकॉर्ड करें</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="931"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="948"/>
         <source>Save note</source>
         <translation>नोट संचित करें</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="932"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="949"/>
         <source>Save recordings</source>
         <translation>रिकॉर्डिंग संचित करें</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="952"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="969"/>
         <source>Select all</source>
         <translation>सभी चयनित करें</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="953"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="970"/>
         <source>Copy</source>
         <translation>कॉपी करेें</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="954"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="971"/>
         <source>Cut</source>
         <translation>कट करें</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="955"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="972"/>
         <source>Paste</source>
         <translation>पेस्ट करें</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="956"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="973"/>
         <source>Delete</source>
         <translation>हटाएँ</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="979"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="996"/>
         <source>Help</source>
         <translation>सहायता</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="980"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="997"/>
         <source>Display shortcuts</source>
         <translation>शॉर्टकट दिखाएँ</translation>
     </message>
@@ -392,22 +392,22 @@
 <context>
     <name>ShortcutsGroups</name>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="908"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="925"/>
         <source>Notebooks</source>
         <translation>नोटबुक</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="936"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="953"/>
         <source>Notes</source>
         <translation>नोट</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="960"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="977"/>
         <source>Edit</source>
         <translation>बदलाव करें</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="984"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="1001"/>
         <source>Settings</source>
         <translation>सेटिंग्स</translation>
     </message>
@@ -415,7 +415,7 @@
 <context>
     <name>SplashView</name>
     <message>
-        <location filename="../src/views/splashview.cpp" line="46"/>
+        <location filename="src/views/splashview.cpp" line="46"/>
         <source>Loading...</source>
         <translation>लोड हो रहा है ...</translation>
     </message>
@@ -423,17 +423,17 @@
 <context>
     <name>TitleBar</name>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="374"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="371"/>
         <source>Search</source>
         <translation>खोजें</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="1869"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="1889"/>
         <source>Settings</source>
         <translation>सेटिंग्स</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="1870"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="1890"/>
         <source>Privacy Policy</source>
         <translation>निजता नीति</translation>
     </message>
@@ -441,7 +441,7 @@
 <context>
     <name>UpgradeView</name>
     <message>
-        <location filename="../src/importolddata/upgradeview.cpp" line="50"/>
+        <location filename="src/importolddata/upgradeview.cpp" line="50"/>
         <source>Importing notes from the old version, please wait...</source>
         <translation>पुराने संस्करण से नोट्स आयात किये जा रहे हैं, प्रतीक्षा करें ...</translation>
     </message>
@@ -449,19 +449,17 @@
 <context>
     <name>Utils</name>
     <message>
-        <location filename="../src/common/utils.cpp" line="56"/>
-        <location filename="../tests/src/common/ut_utils.cpp" line="45"/>
-        <location filename="../tests/src/common/ut_utils.cpp" line="46"/>
+        <location filename="src/common/utils.cpp" line="56"/>
         <source>1 min ago</source>
         <translation>1 मिनट पूर्व</translation>
     </message>
     <message>
-        <location filename="../src/common/utils.cpp" line="58"/>
+        <location filename="src/common/utils.cpp" line="58"/>
         <source>%1 mins ago</source>
         <translation>%1 मिनट पूर्व</translation>
     </message>
     <message>
-        <location filename="../src/common/utils.cpp" line="64"/>
+        <location filename="src/common/utils.cpp" line="64"/>
         <source>Yesterday</source>
         <translation>पिछला कल</translation>
     </message>
@@ -469,12 +467,12 @@
 <context>
     <name>VNoteErrorMessage</name>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="864"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="881"/>
         <source>The voice conversion failed due to the poor network connection, please have a check</source>
         <translation>नेटवर्क धीमा होने के कारण वाणी रूपांतरण विफल रहा, कृपया इसे जाँचें</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="868"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="885"/>
         <source>Voice to text conversion failed</source>
         <translation>वाणी से टेक्स्ट रूपांतरण विफल रहा</translation>
     </message>
@@ -482,7 +480,7 @@
 <context>
     <name>VNoteMainWindow</name>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="467"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="470"/>
         <source>Create Notebook</source>
         <translation>नोटबुक बनाएँ</translation>
     </message>
@@ -490,88 +488,77 @@
 <context>
     <name>VNoteMessageDialog</name>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="53"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="35"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="53"/>
         <source>OK</source>
         <comment>button</comment>
         <translation>ठीक है</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="132"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="101"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="132"/>
         <source>Cancel</source>
         <comment>button</comment>
         <translation>रद्द करें</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="133"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="105"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="133"/>
         <source>Confirm</source>
         <comment>button</comment>
         <translation>पुष्टि करें</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="136"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="46"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="136"/>
         <source>Are you sure you want to delete this notebook?
 All notes in it will be deleted</source>
         <translation>क्या आप इस नोटबुक को हटाना चाहते हैं?
 इसमें सम्मिलित सभी नोट्स भी हटा दिए जायेंगे</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="139"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="53"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="139"/>
         <source>Do you want to stop the current recording?</source>
         <translation>क्या आप वर्तमान रिकॉर्डिंग रोकना चाहते हैं?</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="143"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="94"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="143"/>
         <source>Are you sure you want to delete the selected %1 notes?</source>
         <translation>क्या आप निश्चित ही चयनित %1 नोट हटाना चाहते हैं?</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="145"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="88"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="145"/>
         <source>Are you sure you want to delete this note?</source>
         <translation>क्या आप यह नोट हटाना चाहते हैं?</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="149"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="59"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="149"/>
         <source>Cannot convert this voice note, as notes over 20 minutes are not supported at present.</source>
         <translation>अनुप्रयोग में 20 मिनट से अधिक के नोट समर्थित नहीं है, अतः यह वाणी नोट रूपांतरित नहीं हो सका।</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="153"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="66"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="153"/>
         <source>Converting a voice note now. Do you want to stop it?</source>
         <translation>वाणी नोट रूपांतरित किया जा रहा है। क्या आप इसे रोकना चाहते हैं?</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="156"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="72"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="156"/>
         <source>The low input volume may result in bad recordings. Do you want to continue?</source>
         <translation>इनपुट ध्वनि कम रखने से रिकॉर्डिंग ख़राब होने की संभावना है। क्या आप जारी रखना चाहते हैं? </translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="159"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="79"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="159"/>
         <source>The clipped recordings and converted text will not be pasted. Do you want to continue?</source>
         <translation>कटी रिकॉर्डिंग व रूपांतरित टेक्स्ट पेस्ट नहीं होगा। क्या आप जारी रखना चाहते हैं?</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="162"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="162"/>
         <source>Save failed</source>
         <translation>संचित करना विफल</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="166"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="166"/>
         <source>You do not have permission to save files there</source>
         <translation>आपके पास उस स्थान पर फाइल संचय हेतु अनुमति नहीं है</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="170"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="170"/>
         <source>The voice note has been deleted</source>
         <translation>वाणी नोट हटा दिया गया</translation>
     </message>
@@ -579,12 +566,12 @@ All notes in it will be deleted</source>
 <context>
     <name>VNoteRecordBar</name>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="1714"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="1736"/>
         <source>Your audio recording device does not work.</source>
         <translation>आपका ऑडियो रिकॉर्डिंग उपकरण कार्य नहीं कर रहा है।</translation>
     </message>
     <message>
-        <location filename="../src/views/vnoterecordbar.cpp" line="249"/>
+        <location filename="src/views/vnoterecordbar.cpp" line="249"/>
         <source>No recording device detected</source>
         <translation>कोई ऑडियो रिकॉर्डिंग उपकरण नहीं मिला</translation>
     </message>
@@ -592,7 +579,7 @@ All notes in it will be deleted</source>
 <context>
     <name>VoiceNoteItem</name>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="1657"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="1679"/>
         <source>Converting voice to text</source>
         <translation>वाणी को टेक्स्ट में रूपांतरित किया जा रहा है</translation>
     </message>
@@ -600,57 +587,62 @@ All notes in it will be deleted</source>
 <context>
     <name>web</name>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="138"/>
+        <location filename="src/common/jscontent.cpp" line="141"/>
+        <source>Font</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="src/common/jscontent.cpp" line="142"/>
         <source>Font size</source>
         <translation>मुद्रलिपि आकार</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="139"/>
+        <location filename="src/common/jscontent.cpp" line="143"/>
         <source>Font color</source>
         <translation>मुद्रलिपि रंग</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="140"/>
+        <location filename="src/common/jscontent.cpp" line="144"/>
         <source>Text highlight color</source>
         <translation>चिन्हित टेक्स्ट का रंग</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="141"/>
+        <location filename="src/common/jscontent.cpp" line="145"/>
         <source>Bold</source>
         <translation>मोटे शब्द</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="142"/>
+        <location filename="src/common/jscontent.cpp" line="146"/>
         <source>Italic</source>
         <translation>तिरछे शब्द</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="143"/>
+        <location filename="src/common/jscontent.cpp" line="147"/>
         <source>Underline</source>
         <translation>रेखांकित शब्द</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="144"/>
+        <location filename="src/common/jscontent.cpp" line="148"/>
         <source>Strikethrough</source>
         <translation>मध्य से रेखांखित शब्द</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="145"/>
+        <location filename="src/common/jscontent.cpp" line="149"/>
         <source>Bullets</source>
         <translation>बिंदु अनुक्रमित सूची</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="146"/>
+        <location filename="src/common/jscontent.cpp" line="150"/>
         <source>Numbering</source>
         <translation>अंक अनुक्रमित सूची</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="147"/>
+        <location filename="src/common/jscontent.cpp" line="151"/>
         <source>More colors</source>
         <translation>अधिक रंग</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="148"/>
+        <location filename="src/common/jscontent.cpp" line="152"/>
         <source>Recent</source>
         <translation>हालिया</translation>
     </message>
