@@ -1,21 +1,21 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
 <context>
     <name>AppMain</name>
     <message>
-        <location filename="../src/common/vlcpalyer.cpp" line="54"/>
-        <location filename="../src/main.cpp" line="76"/>
-        <location filename="../src/main.cpp" line="77"/>
-        <location filename="../src/views/vnotemainwindow.cpp" line="605"/>
+        <location filename="src/common/vlcpalyer.cpp" line="54"/>
+        <location filename="src/main.cpp" line="94"/>
+        <location filename="src/main.cpp" line="95"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="615"/>
         <source>Voice Notes</source>
         <translation>Голосовые Заметки</translation>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="78"/>
+        <location filename="src/main.cpp" line="96"/>
         <source>Voice Notes is a lightweight memo tool to make text notes and voice recordings.</source>
         <translation>Голосовые Записки - это легковесный инструмент для создания текстовых заметок и записи голоса.</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="606"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="616"/>
         <source>Recordings not saved</source>
         <translation>Записи не сохранены</translation>
     </message>
@@ -23,18 +23,18 @@
 <context>
     <name>DefaultName</name>
     <message>
-        <location filename="../src/db/vnotefolderoper.cpp" line="245"/>
+        <location filename="src/db/vnotefolderoper.cpp" line="245"/>
         <source>Notebook</source>
         <translation>Записная книжка</translation>
     </message>
     <message>
-        <location filename="../src/db/vnoteitemoper.cpp" line="228"/>
+        <location filename="src/db/vnoteitemoper.cpp" line="228"/>
         <source>Text</source>
         <translation>Текст</translation>
     </message>
     <message>
-        <location filename="../src/db/vnoteitemoper.cpp" line="243"/>
-        <location filename="../src/importolddata/olddbvisistors.cpp" line="154"/>
+        <location filename="src/db/vnoteitemoper.cpp" line="243"/>
+        <location filename="src/importolddata/olddbvisistors.cpp" line="154"/>
         <source>Voice</source>
         <translation>Голос</translation>
     </message>
@@ -42,7 +42,7 @@
 <context>
     <name>DetailPage</name>
     <message>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="213"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="213"/>
         <source>%1 notes selected</source>
         <translation>%1 заметок выбрано</translation>
     </message>
@@ -50,18 +50,18 @@
 <context>
     <name>FolderSelectDialog</name>
     <message>
-        <location filename="../src/dialog/folderselectdialog.cpp" line="217"/>
+        <location filename="src/dialog/folderselectdialog.cpp" line="217"/>
         <source>Move Notes</source>
         <translation>Переместить заметки</translation>
     </message>
     <message>
-        <location filename="../src/dialog/folderselectdialog.cpp" line="244"/>
+        <location filename="src/dialog/folderselectdialog.cpp" line="244"/>
         <source>Cancel</source>
         <comment>button</comment>
         <translation>Отмена</translation>
     </message>
     <message>
-        <location filename="../src/dialog/folderselectdialog.cpp" line="245"/>
+        <location filename="src/dialog/folderselectdialog.cpp" line="245"/>
         <source>Confirm</source>
         <comment>button</comment>
         <translation>Подтвердить</translation>
@@ -70,12 +70,12 @@
 <context>
     <name>HomePage</name>
     <message>
-        <location filename="../src/views/homepage.cpp" line="48"/>
+        <location filename="src/views/homepage.cpp" line="48"/>
         <source>Create Notebook</source>
         <translation>Создать Записную книжку</translation>
     </message>
     <message>
-        <location filename="../src/views/homepage.cpp" line="60"/>
+        <location filename="src/views/homepage.cpp" line="60"/>
         <source>Create a notebook to start recording voice and making notes</source>
         <translation>Создать записную книжку, чтобы начать запись голоса и создания заметок</translation>
     </message>
@@ -83,28 +83,28 @@
 <context>
     <name>LeftView</name>
     <message>
-        <location filename="../src/dialog/folderselectdialog.cpp" line="381"/>
-        <location filename="../src/dialog/folderselectdialog.cpp" line="384"/>
-        <location filename="../src/dialog/folderselectdialog.cpp" line="392"/>
-        <source>Move the note &quot;%1&quot; to:</source>
-        <translation>Переместить заметку &quot;%1&quot; в:</translation>
-    </message>
-    <message>
-        <location filename="../src/dialog/folderselectdialog.cpp" line="380"/>
-        <location filename="../src/dialog/folderselectdialog.cpp" line="394"/>
+        <location filename="src/dialog/folderselectdialog.cpp" line="380"/>
+        <location filename="src/dialog/folderselectdialog.cpp" line="394"/>
         <source>Move %1 notes (%2, ...) to:</source>
         <translation>Переместить %1 заметок (%2, ...) в:</translation>
     </message>
+    <message>
+        <location filename="src/dialog/folderselectdialog.cpp" line="381"/>
+        <location filename="src/dialog/folderselectdialog.cpp" line="384"/>
+        <location filename="src/dialog/folderselectdialog.cpp" line="392"/>
+        <source>Move the note &quot;%1&quot; to:</source>
+        <translation>Переместить заметку &quot;%1&quot; в:</translation>
+    </message>
 </context>
 <context>
     <name>MiddleView</name>
     <message>
-        <location filename="../src/views/middleview.cpp" line="276"/>
+        <location filename="src/views/middleview.cpp" line="303"/>
         <source>Save</source>
         <translation>Сохранить</translation>
     </message>
     <message>
-        <location filename="../src/views/middleview.cpp" line="1070"/>
+        <location filename="src/views/middleview.cpp" line="1057"/>
         <source>No search results</source>
         <translation>Поиск не дал результатов</translation>
     </message>
@@ -112,7 +112,7 @@
 <context>
     <name>MiddleViewDelegate</name>
     <message>
-        <location filename="../src/views/middleviewdelegate.cpp" line="442"/>
+        <location filename="src/views/middleviewdelegate.cpp" line="442"/>
         <source>Sticky Notes</source>
         <translation>Заметки</translation>
     </message>
@@ -120,77 +120,77 @@
 <context>
     <name>NoteDetailContextMenu</name>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="282"/>
+        <location filename="src/common/actionmanager.cpp" line="276"/>
         <source>Save as MP3</source>
         <translation>Сохранить как MP3</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="283"/>
+        <location filename="src/common/actionmanager.cpp" line="277"/>
         <source>Voice to Text</source>
         <translation>Преобразование голосового сообщения в текстовую заметку</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="284"/>
-        <location filename="../src/common/actionmanager.cpp" line="311"/>
-        <location filename="../src/common/actionmanager.cpp" line="337"/>
+        <location filename="src/common/actionmanager.cpp" line="278"/>
+        <location filename="src/common/actionmanager.cpp" line="305"/>
+        <location filename="src/common/actionmanager.cpp" line="331"/>
         <source>Delete</source>
         <translation>Удалить</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="285"/>
-        <location filename="../src/common/actionmanager.cpp" line="312"/>
-        <location filename="../src/common/actionmanager.cpp" line="338"/>
+        <location filename="src/common/actionmanager.cpp" line="279"/>
+        <location filename="src/common/actionmanager.cpp" line="306"/>
+        <location filename="src/common/actionmanager.cpp" line="332"/>
         <source>Select all</source>
         <translation>Выделить все</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="286"/>
-        <location filename="../src/common/actionmanager.cpp" line="313"/>
-        <location filename="../src/common/actionmanager.cpp" line="339"/>
+        <location filename="src/common/actionmanager.cpp" line="280"/>
+        <location filename="src/common/actionmanager.cpp" line="307"/>
+        <location filename="src/common/actionmanager.cpp" line="333"/>
         <source>Copy</source>
         <translation>Копировать</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="287"/>
-        <location filename="../src/common/actionmanager.cpp" line="314"/>
-        <location filename="../src/common/actionmanager.cpp" line="340"/>
+        <location filename="src/common/actionmanager.cpp" line="281"/>
+        <location filename="src/common/actionmanager.cpp" line="308"/>
+        <location filename="src/common/actionmanager.cpp" line="334"/>
         <source>Cut</source>
         <translation>Вырезать</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="288"/>
-        <location filename="../src/common/actionmanager.cpp" line="315"/>
-        <location filename="../src/common/actionmanager.cpp" line="341"/>
+        <location filename="src/common/actionmanager.cpp" line="282"/>
+        <location filename="src/common/actionmanager.cpp" line="309"/>
+        <location filename="src/common/actionmanager.cpp" line="335"/>
         <source>Paste</source>
         <translation>Вставить</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="310"/>
+        <location filename="src/common/actionmanager.cpp" line="304"/>
         <source>View</source>
-        <translation type="unfinished"/>
+        <translation>Просмотр</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="316"/>
+        <location filename="src/common/actionmanager.cpp" line="310"/>
         <source>Save as</source>
-        <translation type="unfinished"/>
+        <translation>Сохранить как</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="342"/>
+        <location filename="src/common/actionmanager.cpp" line="336"/>
         <source>Text to Speech</source>
         <translation>Преобразование текстовой заметки в голосовое сообщение</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="343"/>
+        <location filename="src/common/actionmanager.cpp" line="337"/>
         <source>Stop reading</source>
         <translation>Остановка чтения</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="344"/>
+        <location filename="src/common/actionmanager.cpp" line="338"/>
         <source>Speech to Text</source>
         <translation>Преобразование речи в текстовую заметку</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="345"/>
+        <location filename="src/common/actionmanager.cpp" line="339"/>
         <source>Translate</source>
         <translation>Перевести</translation>
     </message>
@@ -198,17 +198,17 @@
 <context>
     <name>NotebookContextMenu</name>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="226"/>
+        <location filename="src/common/actionmanager.cpp" line="220"/>
         <source>Rename</source>
         <translation>Переименовать</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="227"/>
+        <location filename="src/common/actionmanager.cpp" line="221"/>
         <source>Delete</source>
         <translation>Удалить</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="228"/>
+        <location filename="src/common/actionmanager.cpp" line="222"/>
         <source>New note</source>
         <translation>Новая запись</translation>
     </message>
@@ -216,64 +216,64 @@
 <context>
     <name>NotesContextMenu</name>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="246"/>
-        <source>Rename</source>
-        <translation>Переименовать</translation>
+        <location filename="src/common/actionmanager.cpp" line="195"/>
+        <source>Save as HTML</source>
+        <translation>Сохранить как HTML</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="248"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="336"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="345"/>
-        <source>Move</source>
-        <translation>Переместить</translation>
-    </message>
-    <message>
-        <location filename="../src/common/actionmanager.cpp" line="249"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="338"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="344"/>
-        <source>Delete</source>
-        <translation>Удалить</translation>
-    </message>
-    <message>
-        <location filename="../src/common/actionmanager.cpp" line="201"/>
+        <location filename="src/common/actionmanager.cpp" line="196"/>
         <source>Save as TXT</source>
         <translation>Сохранить  в текстовом формате</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="200"/>
-        <source>Save as HTML</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../src/common/actionmanager.cpp" line="205"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="342"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="353"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="359"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="361"/>
+        <location filename="src/common/actionmanager.cpp" line="200"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="342"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="353"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="359"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="361"/>
         <source>Save note</source>
-        <translation type="unfinished"/>
+        <translation>Сохранить заметку</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="251"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="343"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="354"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="366"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="368"/>
+        <location filename="src/common/actionmanager.cpp" line="240"/>
+        <source>Rename</source>
+        <translation>Переименовать</translation>
+    </message>
+    <message>
+        <location filename="src/common/actionmanager.cpp" line="242"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="336"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="345"/>
+        <source>Move</source>
+        <translation>Переместить</translation>
+    </message>
+    <message>
+        <location filename="src/common/actionmanager.cpp" line="243"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="338"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="344"/>
+        <source>Delete</source>
+        <translation>Удалить</translation>
+    </message>
+    <message>
+        <location filename="src/common/actionmanager.cpp" line="245"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="343"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="354"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="366"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="368"/>
         <source>Save voice recording</source>
         <translation>Сохранить запись голоса</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="252"/>
+        <location filename="src/common/actionmanager.cpp" line="246"/>
         <source>New note</source>
         <translation>Новая запись</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="1240"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="1258"/>
         <source>Unstick</source>
         <translation>Открепить</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="1242"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="1260"/>
         <source>Sticky on Top</source>
         <translation>Прикрепить сверху</translation>
     </message>
@@ -281,22 +281,22 @@
 <context>
     <name>Setting</name>
     <message>
-        <location filename="../src/common/setting.cpp" line="41"/>
+        <location filename="src/common/setting.cpp" line="39"/>
         <source>Basic</source>
         <translation>Основной</translation>
     </message>
     <message>
-        <location filename="../src/common/setting.cpp" line="42"/>
+        <location filename="src/common/setting.cpp" line="40"/>
         <source>Audio Source</source>
         <translation>Источник звука</translation>
     </message>
     <message>
-        <location filename="../src/common/setting.cpp" line="43"/>
+        <location filename="src/common/setting.cpp" line="41"/>
         <source>Internal</source>
         <translation>Внутренний</translation>
     </message>
     <message>
-        <location filename="../src/common/setting.cpp" line="44"/>
+        <location filename="src/common/setting.cpp" line="42"/>
         <source>Microphone</source>
         <translation>Микрофон</translation>
     </message>
@@ -304,87 +304,87 @@
 <context>
     <name>Shortcuts</name>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="902"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="919"/>
         <source>New notebook</source>
         <translation>Новая записная книжка</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="903"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="920"/>
         <source>Rename notebook</source>
         <translation>Переименовать записную книжку</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="904"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="921"/>
         <source>Delete notebook</source>
         <translation>Удалить записную книжку</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="926"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="943"/>
         <source>New note</source>
         <translation>Новая запись</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="927"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="944"/>
         <source>Rename note</source>
         <translation>Переименовать запись</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="928"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="945"/>
         <source>Delete note</source>
         <translation>Удалить запись</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="929"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="946"/>
         <source>Play/Pause</source>
         <translation>Воспроизвести/Пауза</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="930"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="947"/>
         <source>Record voice</source>
         <translation>Запись голоса</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="931"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="948"/>
         <source>Save note</source>
-        <translation type="unfinished"/>
+        <translation>Сохранить заметку</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="932"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="949"/>
         <source>Save recordings</source>
         <translation>Сохранить записи</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="952"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="969"/>
         <source>Select all</source>
         <translation>Выделить все</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="953"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="970"/>
         <source>Copy</source>
         <translation>Копировать</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="954"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="971"/>
         <source>Cut</source>
         <translation>Вырезать</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="955"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="972"/>
         <source>Paste</source>
         <translation>Вставить</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="956"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="973"/>
         <source>Delete</source>
         <translation>Удалить</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="979"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="996"/>
         <source>Help</source>
         <translation>Помощь</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="980"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="997"/>
         <source>Display shortcuts</source>
         <translation>Показать ярлыки</translation>
     </message>
@@ -392,22 +392,22 @@
 <context>
     <name>ShortcutsGroups</name>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="908"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="925"/>
         <source>Notebooks</source>
         <translation>Записные книжки</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="936"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="953"/>
         <source>Notes</source>
         <translation>Записки</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="960"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="977"/>
         <source>Edit</source>
         <translation>Редактирование</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="984"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="1001"/>
         <source>Settings</source>
         <translation>Настройки</translation>
     </message>
@@ -415,7 +415,7 @@
 <context>
     <name>SplashView</name>
     <message>
-        <location filename="../src/views/splashview.cpp" line="46"/>
+        <location filename="src/views/splashview.cpp" line="46"/>
         <source>Loading...</source>
         <translation>Загрузка...</translation>
     </message>
@@ -423,17 +423,17 @@
 <context>
     <name>TitleBar</name>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="374"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="371"/>
         <source>Search</source>
         <translation>Поиск</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="1869"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="1889"/>
         <source>Settings</source>
         <translation>Настройки</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="1870"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="1890"/>
         <source>Privacy Policy</source>
         <translation>Политика конфиденциальности</translation>
     </message>
@@ -441,7 +441,7 @@
 <context>
     <name>UpgradeView</name>
     <message>
-        <location filename="../src/importolddata/upgradeview.cpp" line="50"/>
+        <location filename="src/importolddata/upgradeview.cpp" line="50"/>
         <source>Importing notes from the old version, please wait...</source>
         <translation>Импортирую записи из старой версии, пожалуйста подождите</translation>
     </message>
@@ -449,19 +449,17 @@
 <context>
     <name>Utils</name>
     <message>
-        <location filename="../src/common/utils.cpp" line="56"/>
-        <location filename="../tests/src/common/ut_utils.cpp" line="45"/>
-        <location filename="../tests/src/common/ut_utils.cpp" line="46"/>
+        <location filename="src/common/utils.cpp" line="56"/>
         <source>1 min ago</source>
         <translation>1 минута назад</translation>
     </message>
     <message>
-        <location filename="../src/common/utils.cpp" line="58"/>
+        <location filename="src/common/utils.cpp" line="58"/>
         <source>%1 mins ago</source>
         <translation>%1 минут назад</translation>
     </message>
     <message>
-        <location filename="../src/common/utils.cpp" line="64"/>
+        <location filename="src/common/utils.cpp" line="64"/>
         <source>Yesterday</source>
         <translation>Вчера</translation>
     </message>
@@ -469,20 +467,20 @@
 <context>
     <name>VNoteErrorMessage</name>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="864"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="881"/>
         <source>The voice conversion failed due to the poor network connection, please have a check</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="868"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="885"/>
         <source>Voice to text conversion failed</source>
-        <translation type="unfinished"/>
+        <translation>Не удалось преобразовать голос</translation>
     </message>
 </context>
 <context>
     <name>VNoteMainWindow</name>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="467"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="470"/>
         <source>Create Notebook</source>
         <translation>Создать Записную книжку</translation>
     </message>
@@ -490,87 +488,76 @@
 <context>
     <name>VNoteMessageDialog</name>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="53"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="35"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="53"/>
         <source>OK</source>
         <comment>button</comment>
         <translation>OK</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="132"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="101"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="132"/>
         <source>Cancel</source>
         <comment>button</comment>
         <translation>Отмена</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="133"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="105"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="133"/>
         <source>Confirm</source>
         <comment>button</comment>
         <translation>Подтвердить</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="136"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="46"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="136"/>
         <source>Are you sure you want to delete this notebook?
 All notes in it will be deleted</source>
         <translation>Вы уверены, что хотите удалить эту записную книжку? Все записи в ней будут удалены.</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="139"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="53"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="139"/>
         <source>Do you want to stop the current recording?</source>
         <translation>Остановить текущую запись?</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="143"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="94"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="143"/>
         <source>Are you sure you want to delete the selected %1 notes?</source>
         <translation>Вы уверены, что хотите удалить выделенные %1 записи?</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="145"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="88"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="145"/>
         <source>Are you sure you want to delete this note?</source>
         <translation>Вы уверены, что хотите удалить эту запись?</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="149"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="59"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="149"/>
         <source>Cannot convert this voice note, as notes over 20 minutes are not supported at present.</source>
         <translation>Конвертация голосовой записи невозможна, поскольку заметки продолжительностью более 20 минут в настоящее время не поддерживаются.</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="153"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="66"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="153"/>
         <source>Converting a voice note now. Do you want to stop it?</source>
         <translation>Идет конвертация  голосовой записи. Прервать?</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="156"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="72"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="156"/>
         <source>The low input volume may result in bad recordings. Do you want to continue?</source>
         <translation>Низкая громкость звука  может привести к плохому качеству записи.  Продолжить?</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="159"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="79"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="159"/>
         <source>The clipped recordings and converted text will not be pasted. Do you want to continue?</source>
         <translation>Вырезанные записи и преобразованный текст не будут вставлены.  Продолжить?</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="162"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="162"/>
         <source>Save failed</source>
-        <translation type="unfinished"/>
+        <translation>Сохранение не удалось</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="166"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="166"/>
         <source>You do not have permission to save files there</source>
-        <translation type="unfinished"/>
+        <translation>У вас нет разрешений для сохранения тут файлов</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="170"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="170"/>
         <source>The voice note has been deleted</source>
         <translation>Голосовая запись удалена</translation>
     </message>
@@ -578,12 +565,12 @@ All notes in it will be deleted</source>
 <context>
     <name>VNoteRecordBar</name>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="1714"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="1736"/>
         <source>Your audio recording device does not work.</source>
         <translation>Оборудование для аудио записи не работает.</translation>
     </message>
     <message>
-        <location filename="../src/views/vnoterecordbar.cpp" line="249"/>
+        <location filename="src/views/vnoterecordbar.cpp" line="249"/>
         <source>No recording device detected</source>
         <translation>Устройство записи не обнаружено</translation>
     </message>
@@ -591,7 +578,7 @@ All notes in it will be deleted</source>
 <context>
     <name>VoiceNoteItem</name>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="1657"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="1679"/>
         <source>Converting voice to text</source>
         <translation>Конвертирую  голосовую запись в текстовую заметку.</translation>
     </message>
@@ -599,59 +586,64 @@ All notes in it will be deleted</source>
 <context>
     <name>web</name>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="138"/>
+        <location filename="src/common/jscontent.cpp" line="141"/>
+        <source>Font</source>
+        <translation>Шрифт</translation>
+    </message>
+    <message>
+        <location filename="src/common/jscontent.cpp" line="142"/>
         <source>Font size</source>
-        <translation type="unfinished"/>
+        <translation>Размер шрифта</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="139"/>
+        <location filename="src/common/jscontent.cpp" line="143"/>
         <source>Font color</source>
-        <translation type="unfinished"/>
+        <translation>Цвет шрифта</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="140"/>
+        <location filename="src/common/jscontent.cpp" line="144"/>
         <source>Text highlight color</source>
-        <translation type="unfinished"/>
+        <translation>Текст выделения</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="141"/>
+        <location filename="src/common/jscontent.cpp" line="145"/>
         <source>Bold</source>
-        <translation type="unfinished"/>
+        <translation>Жирный</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="142"/>
+        <location filename="src/common/jscontent.cpp" line="146"/>
         <source>Italic</source>
-        <translation type="unfinished"/>
+        <translation>Курсив</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="143"/>
+        <location filename="src/common/jscontent.cpp" line="147"/>
         <source>Underline</source>
-        <translation type="unfinished"/>
+        <translation>Подчеркнутый</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="144"/>
+        <location filename="src/common/jscontent.cpp" line="148"/>
         <source>Strikethrough</source>
-        <translation type="unfinished"/>
+        <translation>Зачеркнутый</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="145"/>
+        <location filename="src/common/jscontent.cpp" line="149"/>
         <source>Bullets</source>
-        <translation type="unfinished"/>
+        <translation>Маркеры списка</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="146"/>
+        <location filename="src/common/jscontent.cpp" line="150"/>
         <source>Numbering</source>
-        <translation type="unfinished"/>
+        <translation>Нумерация</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="147"/>
+        <location filename="src/common/jscontent.cpp" line="151"/>
         <source>More colors</source>
-        <translation type="unfinished"/>
+        <translation>Дополнительно</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="148"/>
+        <location filename="src/common/jscontent.cpp" line="152"/>
         <source>Recent</source>
-        <translation type="unfinished"/>
+        <translation>Последние</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
